@@ -73,7 +73,7 @@ elections <- function(ID = NULL, type = NULL, start_date = "1900-01-01", end_dat
 
             df$date._datatype <- "POSIXct"
 
-            df <- hansard::hansard_tidy(df, tidy_style)
+            df <- hansard_tidy(df, tidy_style)
 
             df
 
