@@ -1,6 +1,6 @@
 
 
-#' Imports data on House of Lords attendance.
+#' House of Lords attendance.
 #'
 #' Imports data on House of Lords attendance. Please note that the attendance data is not as tidy as some of the others that are accessible through this API, and so additional work to prepare this data in a way that you want may be required.
 #' @param session_id The ID of the House of Lords session. If NULL, returns a list of all sessions. Defaults to NULL.
@@ -67,7 +67,7 @@ lords_attendance <- function(session_id = NULL, start_date = "1900-01-01", end_d
 
             df$date._datatype <- "POSIXct"
 
-            df <- hansard::hansard_tidy(df, tidy_style)
+            df <- hansard_tidy(df, tidy_style)
 
             df
 
