@@ -89,7 +89,7 @@ lords_written_questions <- function(peer_id = NULL, answering_department = NULL,
 
             df$tablingMember._about <- gsub("http://data.parliament.uk/members/", "", df$tablingMember._about)
 
-            df <- hansard::hansard_tidy(df, tidy_style)
+            df <- hansard_tidy(df, tidy_style)
 
             df
 
