@@ -1,5 +1,5 @@
 
-#' Imports data on  Parliamentary Research Briefings.
+#' Parliamentary Research Briefings.
 #'
 #' Imports data on  Parliamentary Research Briefings. To see a list of possible topics call \code{\link{research_topics_list}} or \code{\link{research_subtopics_list}} for both topics and subtopics. To see a list of briefing types, call \code{\link{research_types_list}}. This function can return results with newlines in the text of the abstract or description of the research briefing, represented as '\\n'.
 #' @param topic The topic of the parliamentary briefing.
@@ -140,7 +140,7 @@ research_briefings <- function(topic = NULL, subtopic = NULL, type = NULL, extra
                 }
             }
 
-            df <- hansard::hansard_tidy(df, tidy_style)
+            df <- hansard_tidy(df, tidy_style)
 
         } else {
 
