@@ -5,7 +5,7 @@ test_that("constituencies functions return expected format", {
 
     skip_on_cran()
 
-    ctx <- constituencies(current = TRUE)
+    ctx <- hansard_constituencies(current = TRUE)
     expect_length(ctx, 9)
     expect_true(tibble::is_tibble(ctx))
     expect_equal(nrow(ctx), 650)
